package com.fs.his.service;

import java.util.List;
import com.fs.his.domain.FsAdv;
import com.fs.his.param.FsAdvUParam;
import com.fs.his.vo.FsAdvUVO;

/**
 * 广告Service接口
 *
 * @author fs
 * @date 2023-06-08
 */
public interface IFsAdvService
{
    /**
     * 查询广告
     *
     * @param advId 广告主键
     * @return 广告
     */
    public FsAdv selectFsAdvByAdvId(String advId);

    /**
     * 查询广告列表
     *
     * @param fsAdv 广告
     * @return 广告集合
     */
    public List<FsAdv> selectFsAdvList(FsAdv fsAdv);

    /**
     * 新增广告
     *
     * @param fsAdv 广告
     * @return 结果
     */
    public int insertFsAdv(FsAdv fsAdv);

    /**
     * 修改广告
     *
     * @param fsAdv 广告
     * @return 结果
     */
    public int updateFsAdv(FsAdv fsAdv);

    /**
     * 批量删除广告
     *
     * @param advIds 需要删除的广告主键集合
     * @return 结果
     */
    public int deleteFsAdvByAdvIds(String[] advIds);

    /**
     * 删除广告信息
     *
     * @param advId 广告主键
     * @return 结果
     */
    public int deleteFsAdvByAdvId(String advId);

    List<FsAdv> selectFsAppAdvList();

    List<FsAdv> selectFsAdvListUVO(FsAdvUParam map);

}
